projectal.entities.resource API documentation

# projectal.entities.resource

View Source

     1from projectal.entity import Entity
     2from projectal.linkers import *
     3
     4
     5class Resource(Entity, StaffLinker, TaskLinker, TaskTemplateLinker, NoteLinker,
     6               TagLinker):
     7    """
     8    Implementation of the [Resource](https://projectal.com/docs/latest/#tag/Resource) API.
     9    """
    10    _path = 'resource'
    11    _name = 'resource'
    12    _links = [NoteLinker, TagLinker]
    13    _links_reverse = [StaffLinker, TaskLinker, TaskTemplateLinker]

class Resource(projectal.entity.Entity, projectal.linkers.StaffLinker, projectal.linkers.TaskLinker, projectal.linkers.TaskTemplateLinker, projectal.linkers.NoteLinker, projectal.linkers.TagLinker): View Source

     6class Resource(Entity, StaffLinker, TaskLinker, TaskTemplateLinker, NoteLinker,
     7               TagLinker):
     8    """
     9    Implementation of the [Resource](https://projectal.com/docs/latest/#tag/Resource) API.
    10    """
    11    _path = 'resource'
    12    _name = 'resource'
    13    _links = [NoteLinker, TagLinker]
    14    _links_reverse = [StaffLinker, TaskLinker, TaskTemplateLinker]

Implementation of the Resource API.

##### Inherited Members

projectal.entity.Entity
  get
  update
  delete
  history
  create
  save
  clone
  list
  match
  match_startswith
  match_endswith
  match_one
  match_startswith_one
  match_endswith_one
  search
  query
  profile_get
  profile_set
  changes
  set_readonly
  get_link_definitions
  entity_name
projectal.linkers.StaffLinker
  link_staff
  relink_staff
  unlink_staff
projectal.linkers.TaskLinker
  link_task
  unlink_task
projectal.linkers.TaskTemplateLinker
  link_task_template
  unlink_task_template
projectal.linkers.TagLinker
  link_tag
  unlink_tag
builtins.dict
  setdefault
  pop
  popitem
  keys
  items
  values
  fromkeys
  clear
  copy